@@ -352,43 +352,42 @@ func TestMigrate_New(t *testing.T) {
 	require.FileExists(t, filepath.Join(p, "atlas.sum"))
 	require.Equal(t, 3, countFiles(t, p))
 
-	_, err = runCmd(Root, "migrate", "hash", "--dir", "file://"+p, "--force", "--dir-format", formatGolangMigrate)
-	require.NoError(t, err)
-	MigrateFlags.Force = false
+	p = t.TempDir()
 	s, err = runCmd(Root, "migrate", "new", "golang-migrate", "--dir", "file://"+p, "--dir-format", formatGolangMigrate)
 	require.Zero(t, s)
 	require.NoError(t, err)
 	require.FileExists(t, filepath.Join(p, v+"_golang-migrate.up.sql"))
 	require.FileExists(t, filepath.Join(p, v+"_golang-migrate.down.sql"))
-	require.Equal(t, 5, countFiles(t, p))
+	require.Equal(t, 3, countFiles(t, p))
 
-	s, err = runCmd(Root, "migrate", "hash", "--dir", "file://"+p, "--force", "--dir-format", formatGoose)
-	require.NoError(t, err)
-	MigrateFlags.Force = false
+	p = t.TempDir()
 	s, err = runCmd(Root, "migrate", "new", "goose", "--dir", "file://"+p, "--dir-format", formatGoose)
 	require.Zero(t, s)
 	require.NoError(t, err)
 	require.FileExists(t, filepath.Join(p, v+"_goose.sql"))
-	require.Equal(t, 6, countFiles(t, p))
+	require.Equal(t, 2, countFiles(t, p))
 
+	p = t.TempDir()
 	s, err = runCmd(Root, "migrate", "new", "flyway", "--dir", "file://"+p, "--dir-format", formatFlyway)
 	require.Zero(t, s)
 	require.NoError(t, err)
 	require.FileExists(t, filepath.Join(p, fmt.Sprintf("V%s__%s.sql", v, formatFlyway)))
 	require.FileExists(t, filepath.Join(p, fmt.Sprintf("U%s__%s.sql", v, formatFlyway)))
-	require.Equal(t, 8, countFiles(t, p))
+	require.Equal(t, 3, countFiles(t, p))
 
+	p = t.TempDir()
 	s, err = runCmd(Root, "migrate", "new", "liquibase", "--dir", "file://"+p, "--dir-format", formatLiquibase)
 	require.Zero(t, s)
 	require.NoError(t, err)
 	require.FileExists(t, filepath.Join(p, v+"_liquibase.sql"))
-	require.Equal(t, 9, countFiles(t, p))
+	require.Equal(t, 2, countFiles(t, p))
 
+	p = t.TempDir()
 	s, err = runCmd(Root, "migrate", "new", "dbmate", "--dir", "file://"+p, "--dir-format", formatDbmate)
 	require.Zero(t, s)
 	require.NoError(t, err)
 	require.FileExists(t, filepath.Join(p, v+"_dbmate.sql"))
-	require.Equal(t, 10, countFiles(t, p))
+	require.Equal(t, 2, countFiles(t, p))
 
 	f := filepath.Join("testdata", "mysql", "new.sql")
 	require.NoError(t, os.WriteFile(f, []byte("contents"), 0600))
@@ -400,7 +399,8 @@ func TestMigrate_New(t *testing.T) {
 
 func TestMigrate_Validate(t *testing.T) {
 	// Without re-playing.
-	MigrateFlags.DevURL = "" // global flags are set from other tests ...
+	MigrateFlags.DevURL = ""         // global flags are set from other tests ...
+	MigrateFlags.DirFormat = "atlas" // global flags are set from other tests ...
 	s, err := runCmd(Root, "migrate", "validate", "--dir", "file://testdata/mysql")
 	require.Zero(t, s)
 	require.NoError(t, err)
@@ -419,6 +419,9 @@ func TestMigrate_Validate(t *testing.T) {
 	require.NoError(t, os.WriteFile(filepath.Join(p, "2_second.sql"), []byte("create table t2 (c2 int)"), 0644))
 	_, err = runCmd(Root, "migrate", "hash", "--force", "--dir", "file://"+p)
 	require.NoError(t, err)
+	b, err := os.ReadFile(filepath.Join(p, "1_initial.sql"))
+	require.NoError(t, err)
+	fmt.Println(string(b))
 	s, err = runCmd(
 		Root, "migrate", "validate",
 		"--dir", "file://"+p,
@@ -449,7 +452,7 @@ func TestMigrate_Hash(t *testing.T) {
 	require.NoError(t, err)
 	dir, err := migrate.NewLocalDir(p)
 	require.NoError(t, err)
-	sum, err := migrate.HashSum(dir)
+	sum, err := dir.Checksum()
 	require.NoError(t, err)
 	b, err := sum.MarshalText()
 	require.NoError(t, err)
@@ -486,7 +489,7 @@ func TestMigrate_Lint(t *testing.T) {
 		"--dev-url", openSQLite(t, ""),
 		"--latest", "1",
 	)
-	require.NoError(t, err)
+	require.Error(t, err)
 	require.Equal(t, "Destructive changes detected in file 2.sql:\n\n\tL1: Dropping table \"t\"\n\n", s)
 	s, err = runCmd(
 		Root, "migrate", "lint",
@@ -495,7 +498,7 @@ func TestMigrate_Lint(t *testing.T) {
 		"--latest", "1",
 		"--log", "{{ range .Files }}{{ .Name }}{{ end }}",
 	)
-	require.NoError(t, err)
+	require.Error(t, err)
 	require.Equal(t, "2.sql", s)
 
 	// Change files to golang-migrate format.
