@@ -196,6 +196,9 @@ func (a *Attr) Bools() ([]bool, error) {
 
 // Resource returns the first child Resource by its type and reports whether it was found.
 func (r *Resource) Resource(t string) (*Resource, bool) {
+	if r == nil {
+		return nil, false
+	}
 	for i := range r.Children {
 		if r.Children[i].Type == t {
 			return r.Children[i], true
@@ -219,7 +222,7 @@ func (r *Resource) SetAttr(attr *Attr) {
 }
 
 // MarshalSpec implements Marshaler.
-func (f MarshalerFunc) MarshalSpec(v interface{}) ([]byte, error) {
+func (f MarshalerFunc) MarshalSpec(v any) ([]byte, error) {
 	return f(v)
 }
 
