@@ -349,7 +349,7 @@ func TestExecutor_Baseline(t *testing.T) {
 
 	// Require baseline-version or explicit flag to work on a dirty workspace.
 	files, err := ex.Pending(context.Background())
-	require.EqualError(t, err, "sql/migrate: connected database is not clean: found table. baseline version or allow-dirty are required")
+	require.EqualError(t, err, "sql/migrate: connected database is not clean: found table. baseline version or allow-dirty is required")
 	require.Nil(t, files)
 
 	rrw = mockRevisionReadWriter{}
@@ -438,7 +438,7 @@ func (m *mockDriver) failOn(n int, err error) {
 	m.failWith = err
 }
 
-func (m *mockDriver) ExecContext(_ context.Context, query string, _ ...interface{}) (sql.Result, error) {
+func (m *mockDriver) ExecContext(_ context.Context, query string, _ ...any) (sql.Result, error) {
 	if m.failCounter > 0 {
 		m.failCounter--
 		if m.failCounter == 0 {
