@@ -13,9 +13,9 @@ import (
 
 	"ariga.io/atlas/sql/internal/sqlx"
 	"ariga.io/atlas/sql/migrate"
+	"ariga.io/atlas/sql/mysql/internal/mysqlversion"
 	"ariga.io/atlas/sql/schema"
 	"ariga.io/atlas/sql/sqlclient"
-	"golang.org/x/mod/semver"
 )
 
 type (
@@ -32,15 +32,18 @@ type (
 	conn struct {
 		schema.ExecQuerier
 		// System variables that are set on `Open`.
-		version string
+		mysqlversion.V
 		collate string
 		charset string
 	}
 )
 
+// DriverName holds the name used for registration.
+const DriverName = "mysql"
+
 func init() {
 	sqlclient.Register(
-		"mysql",
+		DriverName,
 		sqlclient.DriverOpener(Open),
 		sqlclient.RegisterCodec(MarshalHCL, EvalHCL),
 		sqlclient.RegisterFlavours("maria", "mariadb"),
@@ -55,20 +58,20 @@ func Open(db schema.ExecQuerier) (migrate.Driver, error) {
 	if err != nil {
 		return nil, fmt.Errorf("mysql: query system variables: %w", err)
 	}
-	if err := sqlx.ScanOne(rows, &c.version, &c.collate, &c.charset); err != nil {
+	if err := sqlx.ScanOne(rows, &c.V, &c.collate, &c.charset); err != nil {
 		return nil, fmt.Errorf("mysql: scan system variables: %w", err)
 	}
-	if c.tidb() {
+	if c.TiDB() {
 		return &Driver{
 			conn:        c,
-			Differ:      &sqlx.Diff{DiffDriver: &tdiff{diff{c}}},
+			Differ:      &sqlx.Diff{DiffDriver: &tdiff{diff{conn: c}}},
 			Inspector:   &tinspect{inspect{c}},
 			PlanApplier: &tplanApply{planApply{c}},
 		}, nil
 	}
 	return &Driver{
 		conn:        c,
-		Differ:      &sqlx.Diff{DiffDriver: &diff{c}},
+		Differ:      &sqlx.Diff{DiffDriver: &diff{conn: c}},
 		Inspector:   &inspect{c},
 		PlanApplier: &planApply{c},
 	}, nil
@@ -114,6 +117,82 @@ func (d *Driver) Lock(ctx context.Context, name string, timeout time.Duration) (
 	}, nil
 }
 
+// Snapshot implements migrate.Snapshoter.
+func (d *Driver) Snapshot(ctx context.Context) (migrate.RestoreFunc, error) {
+	// If the connection is bound to a schema, we can restore the state if the schema has no tables.
+	s, err := d.InspectSchema(ctx, "", nil)
+	if err != nil && !schema.IsNotExistError(err) {
+		return nil, err
+	}
+	// If a schema was found, it has to have no tables attached to be considered clean.
+	if s != nil {
+		if len(s.Tables) > 0 {
+			return nil, migrate.NotCleanError{Reason: fmt.Sprintf("found table %q in schema %q", s.Tables[0].Name, s.Name)}
+		}
+		return func(ctx context.Context) error {
+			current, err := d.InspectSchema(ctx, s.Name, nil)
+			if err != nil {
+				return err
+			}
+			changes, err := d.SchemaDiff(current, s)
+			if err != nil {
+				return err
+			}
+			return d.ApplyChanges(ctx, changes)
+		}, nil
+	}
+	// Otherwise, the database can not have any schema.
+	realm, err := d.InspectRealm(ctx, nil)
+	if err != nil {
+		return nil, err
+	}
+	if len(realm.Schemas) > 0 {
+		return nil, migrate.NotCleanError{Reason: fmt.Sprintf("found schema %q", realm.Schemas[0].Name)}
+	}
+	return func(ctx context.Context) error {
+		current, err := d.InspectRealm(ctx, nil)
+		if err != nil {
+			return err
+		}
+		changes, err := d.RealmDiff(current, realm)
+		if err != nil {
+			return err
+		}
+		return d.ApplyChanges(ctx, changes)
+	}, nil
+}
+
+// CheckClean implements migrate.CleanChecker.
+func (d *Driver) CheckClean(ctx context.Context, revT *migrate.TableIdent) error {
+	s, err := d.InspectSchema(ctx, "", nil)
+	if err != nil && !schema.IsNotExistError(err) {
+		return err
+	}
+	if s != nil {
+		switch {
+		case len(s.Tables) == 0, (revT.Schema == "" || s.Name == revT.Schema) && len(s.Tables) == 1 && s.Tables[0].Name == revT.Name:
+			return nil
+		default:
+			return &migrate.NotCleanError{Reason: fmt.Sprintf("found table %q in schema %q", s.Tables[0].Name, s.Name)}
+		}
+	}
+	r, err := d.InspectRealm(ctx, nil)
+	if err != nil {
+		return err
+	}
+	switch n := len(r.Schemas); {
+	case n > 1:
+		return migrate.NotCleanError{Reason: fmt.Sprintf("found multiple schemas: %d", len(r.Schemas))}
+	case n == 1 && r.Schemas[0].Name != revT.Schema:
+		return migrate.NotCleanError{Reason: fmt.Sprintf("found schema %q", r.Schemas[0].Name)}
+	case n == 1 && len(r.Schemas[0].Tables) > 1:
+		return migrate.NotCleanError{Reason: fmt.Sprintf("found multiple tables: %d", len(r.Schemas[0].Tables))}
+	case n == 1 && len(r.Schemas[0].Tables) == 1 && r.Schemas[0].Tables[0].Name != revT.Name:
+		return migrate.NotCleanError{Reason: fmt.Sprintf("found table %q", r.Schemas[0].Tables[0].Name)}
+	}
+	return nil
+}
+
 func acquire(ctx context.Context, conn schema.ExecQuerier, name string, timeout time.Duration) error {
 	rows, err := conn.QueryContext(ctx, "SELECT GET_LOCK(?, ?)", name, int(timeout.Seconds()))
 	if err != nil {
@@ -131,92 +210,6 @@ func acquire(ctx context.Context, conn schema.ExecQuerier, name string, timeout
 	return nil
 }
 
-// supportsCheck reports if the connected database supports
-// the CHECK clause, and return the querying for getting them.
-func (d *conn) supportsCheck() (string, bool) {
-	v, q := "8.0.16", myChecksQuery
-	if d.mariadb() {
-		v, q = "10.2.1", marChecksQuery
-	}
-	return q, d.gteV(v)
-}
-
-// supportsIndexExpr reports if the connected database supports
-// index expressions (functional key part).
-func (d *conn) supportsIndexExpr() bool {
-	return !d.mariadb() && d.gteV("8.0.13")
-}
-
-// supportsDisplayWidth reports if the connected database supports
-// getting the display width information from the information schema.
-func (d *conn) supportsDisplayWidth() bool {
-	// MySQL v8.0.19 dropped the display width
-	// information from the information schema
-	return d.mariadb() || d.ltV("8.0.19")
-}
-
-// supportsExprDefault reports if the connected database supports
-// expressions in the DEFAULT clause on column definition.
-func (d *conn) supportsExprDefault() bool {
-	v := "8.0.13"
-	if d.mariadb() {
-		v = "10.2.1"
-	}
-	return d.gteV(v)
-}
-
-// supportsEnforceCheck reports if the connected database supports
-// the ENFORCED option in CHECK constraint syntax.
-func (d *conn) supportsEnforceCheck() bool {
-	return !d.mariadb() && d.gteV("8.0.16")
-}
-
-// supportsGeneratedColumns reports if the connected database
-// supports the generated columns in information schema.
-func (d *conn) supportsGeneratedColumns() bool {
-	v := "5.7"
-	if d.mariadb() {
-		v = "10.2"
-	}
-	return d.gteV(v)
-}
-
-// supportsRenameColumn reports if the connected database
-// supports the "RENAME COLUMN" clause.
-func (d *conn) supportsRenameColumn() bool {
-	v := "8"
-	if d.mariadb() {
-		v = "10.5.2"
-	}
-	return d.gteV(v)
-}
-
-// mariadb reports if the Driver is connected to a MariaDB database.
-func (d *conn) mariadb() bool {
-	return strings.Index(d.version, "MariaDB") > 0
-}
-
-// tidb reports if the Driver is connected to a TiDB database.
-func (d *conn) tidb() bool {
-	return strings.Index(d.version, "TiDB") > 0
-}
-
-// compareV returns an integer comparing two versions according to
-// semantic version precedence.
-func (d *conn) compareV(w string) int {
-	v := d.version
-	if d.mariadb() {
-		v = v[:strings.Index(v, "MariaDB")-1]
-	}
-	return semver.Compare("v"+v, "v"+w)
-}
-
-// gteV reports if the connection version is >= w.
-func (d *conn) gteV(w string) bool { return d.compareV(w) >= 0 }
-
-// ltV reports if the connection version is < w.
-func (d *conn) ltV(w string) bool { return d.compareV(w) == -1 }
-
 // unescape strings with backslashes returned
 // for SQL expressions from information schema.
 func unescape(s string) string {
