@@ -118,7 +118,15 @@ func Open(db schema.ExecQuerier) (migrate.Driver, error) {
 }
 
 func (d *Driver) dev() *sqlx.DevDriver {
-	return &sqlx.DevDriver{Driver: d, MaxNameLen: 63}
+	return &sqlx.DevDriver{
+		Driver:     d,
+		MaxNameLen: 63,
+		PatchColumn: func(s *schema.Schema, c *schema.Column) {
+			if e, ok := hasEnumType(c); ok {
+				e.Schema = s
+			}
+		},
+	}
 }
 
 // NormalizeRealm returns the normal representation of the given database.
